# autobean-format
[![build](https://github.com/SEIAROTg/autobean-format/actions/workflows/build.yml/badge.svg)](https://github.com/SEIAROTg/autobean-format/actions/workflows/build.yml)
[![pypi](https://img.shields.io/pypi/v/autobean-format)](https://pypi.org/project/autobean-format/)
[![Test Coverage](https://api.codeclimate.com/v1/badges/0c09f58b4d6735d7d991/test_coverage)](https://codeclimate.com/github/SEIAROTg/autobean-format/test_coverage)
[![Maintainability](https://api.codeclimate.com/v1/badges/0c09f58b4d6735d7d991/maintainability)](https://codeclimate.com/github/SEIAROTg/autobean-format/maintainability)
[![license](https://img.shields.io/github/license/SEIAROTg/autobean-format.svg)](https://github.com/SEIAROTg/autobean-format)

Yet another formatter for beancount.

## Usage

```sh
$ pip install autobean-format
$ autobean-format -h
```

## Features

* Recursively format included files.
* Add / remove thousands separators in numbers.
